# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.7.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1EnvFromSource(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, config_map_ref=None, prefix=None, secret_ref=None):
        """
        V1EnvFromSource - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'config_map_ref': 'V1ConfigMapEnvSource',
            'prefix': 'str',
            'secret_ref': 'V1SecretEnvSource'
        }

        self.attribute_map = {
            'config_map_ref': 'configMapRef',
            'prefix': 'prefix',
            'secret_ref': 'secretRef'
        }

        self._config_map_ref = config_map_ref
        self._prefix = prefix
        self._secret_ref = secret_ref

    @property
    def config_map_ref(self):
        """
        Gets the config_map_ref of this V1EnvFromSource.
        The ConfigMap to select from

        :return: The config_map_ref of this V1EnvFromSource.
        :rtype: V1ConfigMapEnvSource
        """
        return self._config_map_ref

    @config_map_ref.setter
    def config_map_ref(self, config_map_ref):
        """
        Sets the config_map_ref of this V1EnvFromSource.
        The ConfigMap to select from

        :param config_map_ref: The config_map_ref of this V1EnvFromSource.
        :type: V1ConfigMapEnvSource
        """

        self._config_map_ref = config_map_ref

    @property
    def prefix(self):
        """
        Gets the prefix of this V1EnvFromSource.
        An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.

        :return: The prefix of this V1EnvFromSource.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this V1EnvFromSource.
        An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.

        :param prefix: The prefix of this V1EnvFromSource.
        :type: str
        """

        self._prefix = prefix

    @property
    def secret_ref(self):
        """
        Gets the secret_ref of this V1EnvFromSource.
        The Secret to select from

        :return: The secret_ref of this V1EnvFromSource.
        :rtype: V1SecretEnvSource
        """
        return self._secret_ref

    @secret_ref.setter
    def secret_ref(self, secret_ref):
        """
        Sets the secret_ref of this V1EnvFromSource.
        The Secret to select from

        :param secret_ref: The secret_ref of this V1EnvFromSource.
        :type: V1SecretEnvSource
        """

        self._secret_ref = secret_ref

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1EnvFromSource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
